Ordina su Music House Bari
Description: Compila il modulo sottostante per ordinare il tuo prodotto da Music House.

Home page Orari Chi siamo Dove siamo
| Cerca: |
Ti trovi in: Strumenti musicali » Amplificazione » Monitor da Studio » Alesis M1Active monitor MK2 coppia di monitor bi amplificati » Acquista
Alcuni marchi Modalità di pagamento Contrassegno Bonifico per l'Italia Bonifico per l'Estero Postepay Informazioni |
# Acquista Compila il seguente modulo per acquistare un oggetto dal nostro negozio. Tutti i prezzi sono IVA inclusa. Le voci contrassegnate in rosso e dal cancelletto (#) sono obbligatorie. Carrello
Quant. | Prodotto | Prezzo online | Prezzo in negozio
--- | --- | --- | ---
1x | Alesis M1Active monitor MK2 coppia di monitor bi amplificati | € 430,00 | € 450,00
Disponibile per Acquista online e ricevi a casa con corriere (€ 90,00) Nel caso la spedizione è assicurata, il prodotto viaggerà assicurato per il suo VALORE EFFETTIVO. Acquista online e ricevi a casa con corriere su appuntamento (€ 106,00) Indicare nel campo NOTE il giorno e l'ora in cui il corriere dovrà consegnare la merce. Acquista e paga online con bonifico anticipato, poi ritira nel nostro negozio di Bari Essendo una vendita online, al prezzo online di € 430,00, il collo verrà ritirato chiuso e seguirà le regole di vendita online. Sarà necessario inviare per mezzo fax o e-mail la ricevuta del pagamento EFFETTUATO soltanto con bonifico bancario ANTICIPATO. La merce potrà essere ritirata solo dopo l'accredito sul nostro conto corrente (da 3 a 8 giorni lavorativi) e il ricevimento di una nostra email di AVVISO RITIRO PRODOTTO". Prova e acquista (anche a rate) nel nostro negozio di Bari Il prezzo in negozio è di € 450,00 Euro. Costo spedizione: + Euro Metodo di pagamento Scegli la modalità di pagamento da te preferita. Per importi superiori ai € 800,00 Euro è obbligatorio il bonifico bancario anticipato. PayPal o carte di credito Bonifico bancario anticipato* Contrassegno** (€ 18,00 Euro) Postepay (€ 2,00 Euro) *Sarà necessario inviare per mezzo fax o e-mail la ricevuta del pagamento con bonifico bancario entro le 48 ore dall'ordine, pena la cancellazione dell'ordine stesso; la merce sarà spedita dopo l'accredito sul nostro conto corrente (da 1 a 5 giorni lavorativi).. **Pagamento in contanti al corriere alla consegna del pacco (non si accettano assegni bancari o circolari). La merce verrà spedita solo dopo aver ricevuto in anticipo e per mezzo bonifico bancario il costo del trasporto e del contrassegno. Tale somma è da considerarsi come caparra penitenziale: per tanto qualora il corriere fosse impossibilitato a consegnare la merce per colpa del Cliente (ad esempio: assenza del Cliente al momento della consegna), tale caparra non verrà rimborsata da Music House al Cliente. Costo modalità di pagamento: + Euro Totale TOTALE complessivo da pagare (IVA inclusa): Euro Dati per la spedizione # Nome: # Cognome: # Indirizzo: # N. civico: # CAP: # Provincia: # Città: # Telefono fisso: Telefono cellulare: # E-mail: # Data di nascita: (Se non hai ancora compiuto i 18 anni, l'ordine deve essere effettuato dal genitore esercente la tua potestà) # Codice fiscale: Destinazione diversa Se desideri ricevere la merce ad un indirizzo diverso, clicca qui: Nome e cognome / Ragione sociale: Indirizzo: N. civico: CAP: Provincia: Città: Telefono: Partita IVA: Informazioni finali Eventuali prodotti o accessori che vuoi acquistare: Voglio iscrivermi alla newsletter e ricevere offerte, sconti e promozioni via e-mail (servizio gratuito); # Ho letto ed accetto le condizioni di vendita, i tempi e le modalità di spedizione e di pagamento; # Esprimo il consenso al trattamento dei miei dati personali (D. Lgs. 196/2003) così come fa informativa di cui ho preso visione e approvo. Concludi l'ordine Si prega di ricontrollare tutti i dati inseriti prima di fare click sul bottone sottostante "Acquista", grazie.
Condizioni di vendita | Post vendita | Diritto di recesso | Privacy | FAQ | Lavora con noi | Sei un rivenditore? | Link Log-in Music House Bari - P. IVA: 04718980727 Music House è in viale Einaudi 12/abc, 70125 BARI (Italy) Tel/Fax: 080/5019521 Tutti i nomi dei prodotti, i logotipi, i marchi ed i simboli sono di proprietà delle rispettive società. © Copyright 2005-2015 Aproweb. Tutti i diritti riservati. Pagina elaborata in 0,0469 secondi.